% -*- coding: utf-8; Mode: erlang; tab-width: 4; c-basic-offset: 4; indent-tabs-mode: nil -*-
% ex: set softtabstop=4 tabstop=4 shiftwidth=4 expandtab fileencoding=utf-8:
%% coding: utf-8

%% @author Marc Worrell <marc@worrell.nl>
%% @doc Mapping of iso code to country name in english
%% @copyright 2011-2015 Marc Worrell

-module(l10n_iso2country).

-author("Marc Worrell <marc@worrell.nl>").

-export([
    iso2country/0,
    iso2country/1
]).


iso2country(Iso) ->
    case lists:keyfind(Iso, 1, iso2country()) of
        {_, Name} -> Name;
        false -> undefined
    end.


-ifdef(coding_utf8).
iso2country() -> [
	{<<"af">>, <<"Afghanistan"/utf8>>},
	{<<"al">>, <<"Albania"/utf8>>},
	{<<"ax">>, <<"Åland Islands"/utf8>>},
	{<<"dz">>, <<"Algeria"/utf8>>},
	{<<"as">>, <<"American Samoa"/utf8>>},
	{<<"ad">>, <<"Andorra"/utf8>>},
	{<<"ao">>, <<"Angola"/utf8>>},
	{<<"ai">>, <<"Anguilla"/utf8>>},
	{<<"aq">>, <<"Antarctica"/utf8>>},
	{<<"ag">>, <<"Antigua and Barbuda"/utf8>>},
	{<<"ar">>, <<"Argentina"/utf8>>},
	{<<"am">>, <<"Armenia"/utf8>>},
	{<<"aw">>, <<"Aruba"/utf8>>},
	{<<"au">>, <<"Australia"/utf8>>},
	{<<"at">>, <<"Austria"/utf8>>},
	{<<"az">>, <<"Azerbaijan"/utf8>>},
	{<<"bs">>, <<"Bahamas"/utf8>>},
	{<<"bh">>, <<"Bahrain"/utf8>>},
	{<<"bd">>, <<"Bangladesh"/utf8>>},
	{<<"bb">>, <<"Barbados"/utf8>>},
	{<<"by">>, <<"Belarus"/utf8>>},
	{<<"be">>, <<"Belgium"/utf8>>},
	{<<"bz">>, <<"Belize"/utf8>>},
	{<<"bj">>, <<"Benin"/utf8>>},
	{<<"bm">>, <<"Bermuda"/utf8>>},
	{<<"bt">>, <<"Bhutan"/utf8>>},
	{<<"bo">>, <<"Bolivia"/utf8>>},
	{<<"bq">>, <<"Bonaire, Sint Eustatius and Saba"/utf8>>},
	{<<"ba">>, <<"Bosnia-Herzegovina"/utf8>>},
	{<<"bw">>, <<"Botswana"/utf8>>},
	{<<"bv">>, <<"Bouvet Island"/utf8>>},
	{<<"br">>, <<"Brazil"/utf8>>},
	{<<"io">>, <<"British Indian Ocean Territory"/utf8>>},
	{<<"bn">>, <<"Brunei Darussalam"/utf8>>},
	{<<"bg">>, <<"Bulgaria"/utf8>>},
	{<<"bf">>, <<"Burkina Faso"/utf8>>},
	{<<"bi">>, <<"Burundi"/utf8>>},
	{<<"kh">>, <<"Cambodia"/utf8>>},
	{<<"cm">>, <<"Cameroon"/utf8>>},
	{<<"ca">>, <<"Canada"/utf8>>},
	{<<"cv">>, <<"Cape Verde"/utf8>>},
	{<<"ky">>, <<"Cayman Islands"/utf8>>},
	{<<"cf">>, <<"Central African Republic"/utf8>>},
	{<<"td">>, <<"Chad"/utf8>>},
	{<<"cl">>, <<"Chile"/utf8>>},
	{<<"cn">>, <<"China"/utf8>>},
	{<<"cx">>, <<"Christmas Island"/utf8>>},
	{<<"cc">>, <<"Cocos (Keeling) Islands"/utf8>>},
	{<<"co">>, <<"Colombia"/utf8>>},
	{<<"km">>, <<"Comoros"/utf8>>},
	{<<"cg">>, <<"Congo"/utf8>>},
	{<<"cd">>, <<"Congo, The Democratic Republic of the"/utf8>>},
	{<<"ck">>, <<"Cook Islands"/utf8>>},
	{<<"cr">>, <<"Costa Rica"/utf8>>},
	{<<"hr">>, <<"Croatia"/utf8>>},
	{<<"cu">>, <<"Cuba"/utf8>>},
	{<<"cw">>, <<"Curaçao"/utf8>>},
	{<<"cy">>, <<"Cyprus"/utf8>>},
	{<<"cz">>, <<"Czech Republic"/utf8>>},
	{<<"dk">>, <<"Denmark"/utf8>>},
	{<<"dj">>, <<"Djibouti"/utf8>>},
	{<<"dm">>, <<"Dominica"/utf8>>},
	{<<"do">>, <<"Dominican Republic"/utf8>>},
	{<<"tp">>, <<"East Timor"/utf8>>},
	{<<"ec">>, <<"Ecuador"/utf8>>},
	{<<"eg">>, <<"Egypt"/utf8>>},
	{<<"sv">>, <<"El Salvador"/utf8>>},
	{<<"gq">>, <<"Equatorial Guinea"/utf8>>},
	{<<"er">>, <<"Eritrea"/utf8>>},
	{<<"ee">>, <<"Estonia"/utf8>>},
	{<<"et">>, <<"Ethiopia"/utf8>>},
	{<<"fk">>, <<"Falkland Islands"/utf8>>},
	{<<"fo">>, <<"Faroe Islands"/utf8>>},
	{<<"fj">>, <<"Fiji"/utf8>>},
	{<<"fi">>, <<"Finland"/utf8>>},
	{<<"fr">>, <<"France"/utf8>>},
	{<<"gf">>, <<"French Guiana"/utf8>>},
	{<<"pf">>, <<"French Polynesia"/utf8>>},
	{<<"tf">>, <<"French Southern Territories"/utf8>>},
	{<<"ga">>, <<"Gabon"/utf8>>},
	{<<"gm">>, <<"Gambia"/utf8>>},
	{<<"ge">>, <<"Georgia"/utf8>>},
	{<<"de">>, <<"Germany"/utf8>>},
	{<<"gh">>, <<"Ghana"/utf8>>},
	{<<"gi">>, <<"Gibraltar"/utf8>>},
	{<<"gr">>, <<"Greece"/utf8>>},
	{<<"gl">>, <<"Greenland"/utf8>>},
	{<<"gd">>, <<"Grenada"/utf8>>},
	{<<"gp">>, <<"Guadeloupe"/utf8>>},
	{<<"gu">>, <<"Guam"/utf8>>},
	{<<"gt">>, <<"Guatemala"/utf8>>},
	{<<"gg">>, <<"Guernsey"/utf8>>},
	{<<"gn">>, <<"Guinea"/utf8>>},
	{<<"gw">>, <<"Guinea Bissau"/utf8>>},
	{<<"gy">>, <<"Guyana"/utf8>>},
	{<<"ht">>, <<"Haiti"/utf8>>},
	{<<"hm">>, <<"Heard and McDonald Islands"/utf8>>},
	{<<"va">>, <<"Holy See (Vatican City State)"/utf8>>},
	{<<"hn">>, <<"Honduras"/utf8>>},
	{<<"hk">>, <<"Hong Kong"/utf8>>},
	{<<"hu">>, <<"Hungary"/utf8>>},
	{<<"is">>, <<"Iceland"/utf8>>},
	{<<"in">>, <<"India"/utf8>>},
	{<<"id">>, <<"Indonesia"/utf8>>},
	{<<"ir">>, <<"Iran"/utf8>>},
	{<<"iq">>, <<"Iraq"/utf8>>},
	{<<"ie">>, <<"Ireland"/utf8>>},
	{<<"il">>, <<"Israel"/utf8>>},
	{<<"im">>, <<"Isle of Man"/utf8>>},
	{<<"it">>, <<"Italy"/utf8>>},
	{<<"ci">>, <<"Ivory Coast (Cote D'Ivoire)"/utf8>>},
	{<<"jm">>, <<"Jamaica"/utf8>>},
	{<<"jp">>, <<"Japan"/utf8>>},
	{<<"je">>, <<"Jersey"/utf8>>},
	{<<"jo">>, <<"Jordan"/utf8>>},
	{<<"kz">>, <<"Kazakhstan"/utf8>>},
	{<<"ke">>, <<"Kenya"/utf8>>},
	{<<"ki">>, <<"Kiribati"/utf8>>},
	{<<"xk">>, <<"Kosovo"/utf8>>},
	{<<"kw">>, <<"Kuwait"/utf8>>},
	{<<"kg">>, <<"Kyrgyzstan"/utf8>>},
	{<<"la">>, <<"Laos"/utf8>>},
	{<<"lv">>, <<"Latvia"/utf8>>},
	{<<"lb">>, <<"Lebanon"/utf8>>},
	{<<"ls">>, <<"Lesotho"/utf8>>},
	{<<"lr">>, <<"Liberia"/utf8>>},
	{<<"ly">>, <<"Libya"/utf8>>},
	{<<"li">>, <<"Liechtenstein"/utf8>>},
	{<<"lt">>, <<"Lithuania"/utf8>>},
	{<<"lu">>, <<"Luxembourg"/utf8>>},
	{<<"mo">>, <<"Macao"/utf8>>},
	{<<"mk">>, <<"Macedonia"/utf8>>},
	{<<"mg">>, <<"Madagascar"/utf8>>},
	{<<"mw">>, <<"Malawi"/utf8>>},
	{<<"my">>, <<"Malaysia"/utf8>>},
	{<<"mv">>, <<"Maldives"/utf8>>},
	{<<"ml">>, <<"Mali"/utf8>>},
	{<<"mt">>, <<"Malta"/utf8>>},
	{<<"mh">>, <<"Marshall Islands"/utf8>>},
	{<<"mq">>, <<"Martinique"/utf8>>},
	{<<"mr">>, <<"Mauritania"/utf8>>},
	{<<"mu">>, <<"Mauritius"/utf8>>},
	{<<"yt">>, <<"Mayotte"/utf8>>},
	{<<"mx">>, <<"Mexico"/utf8>>},
	{<<"fm">>, <<"Micronesia"/utf8>>},
	{<<"md">>, <<"Moldova"/utf8>>},
	{<<"mc">>, <<"Monaco"/utf8>>},
	{<<"mn">>, <<"Mongolia"/utf8>>},
	{<<"me">>, <<"Montenegro"/utf8>>},
	{<<"ms">>, <<"Montserrat"/utf8>>},
	{<<"ma">>, <<"Morocco"/utf8>>},
	{<<"mz">>, <<"Mozambique"/utf8>>},
	{<<"mm">>, <<"Myanmar"/utf8>>},
	{<<"na">>, <<"Namibia"/utf8>>},
	{<<"nr">>, <<"Nauru"/utf8>>},
	{<<"np">>, <<"Nepal"/utf8>>},
	{<<"nl">>, <<"Netherlands"/utf8>>},
	{<<"nc">>, <<"New Caledonia"/utf8>>},
	{<<"nz">>, <<"New Zealand"/utf8>>},
	{<<"ni">>, <<"Nicaragua"/utf8>>},
	{<<"ne">>, <<"Niger"/utf8>>},
	{<<"ng">>, <<"Nigeria"/utf8>>},
	{<<"nu">>, <<"Niue"/utf8>>},
	{<<"nf">>, <<"Norfolk Island"/utf8>>},
	{<<"kp">>, <<"North Korea"/utf8>>},
	{<<"mp">>, <<"Northern Mariana Islands"/utf8>>},
	{<<"no">>, <<"Norway"/utf8>>},
	{<<"om">>, <<"Oman"/utf8>>},
	{<<"pk">>, <<"Pakistan"/utf8>>},
	{<<"pw">>, <<"Palau"/utf8>>},
	{<<"pa">>, <<"Panama"/utf8>>},
	{<<"pg">>, <<"Papua New Guinea"/utf8>>},
	{<<"py">>, <<"Paraguay"/utf8>>},
	{<<"pe">>, <<"Peru"/utf8>>},
	{<<"ph">>, <<"Philippines"/utf8>>},
	{<<"pn">>, <<"Pitcairn Island"/utf8>>},
	{<<"pl">>, <<"Poland"/utf8>>},
	{<<"ps">>, <<"Palestinian Territory, Occupied"/utf8>>},
	{<<"pt">>, <<"Portugal"/utf8>>},
	{<<"pr">>, <<"Puerto Rico"/utf8>>},
	{<<"qa">>, <<"Qatar"/utf8>>},
	{<<"re">>, <<"Reunion"/utf8>>},
	{<<"ro">>, <<"Romania"/utf8>>},
	{<<"ru">>, <<"Russian Federation"/utf8>>},
	{<<"rw">>, <<"Rwanda"/utf8>>},
	{<<"gs">>, <<"South Georgia and the South Sandwich Islands"/utf8>>},
	{<<"bl">>, <<"Saint Barthélemy"/utf8>>},
	{<<"sh">>, <<"Saint Helena"/utf8>>},
	{<<"kn">>, <<"Saint Kitts and Nevis Anguilla"/utf8>>},
	{<<"lc">>, <<"Saint Lucia"/utf8>>},
	{<<"mf">>, <<"Saint Martin (French)"/utf8>>},
	{<<"sx">>, <<"Sint Maarten (Dutch)"/utf8>>},
	{<<"pm">>, <<"Saint Pierre and Miquelon"/utf8>>},
	{<<"st">>, <<"Sao Tome and Principe"/utf8>>},
	{<<"vc">>, <<"Saint Vincent and Grenadines"/utf8>>},
	{<<"ws">>, <<"Samoa"/utf8>>},
	{<<"sm">>, <<"San Marino"/utf8>>},
	{<<"sa">>, <<"Saudi Arabia"/utf8>>},
	{<<"sn">>, <<"Senegal"/utf8>>},
	{<<"rs">>, <<"Serbia"/utf8>>},
	{<<"sc">>, <<"Seychelles"/utf8>>},
	{<<"sl">>, <<"Sierra Leone"/utf8>>},
	{<<"sg">>, <<"Singapore"/utf8>>},
	{<<"sk">>, <<"Slovakia"/utf8>>},
	{<<"si">>, <<"Slovenia"/utf8>>},
	{<<"sb">>, <<"Solomon Islands"/utf8>>},
	{<<"so">>, <<"Somalia"/utf8>>},
	{<<"za">>, <<"South Africa"/utf8>>},
	{<<"kr">>, <<"South Korea"/utf8>>},
	{<<"ss">>, <<"South Sudan"/utf8>>},
	{<<"es">>, <<"Spain"/utf8>>},
	{<<"lk">>, <<"Sri Lanka"/utf8>>},
	{<<"sd">>, <<"Sudan"/utf8>>},
	{<<"sr">>, <<"Suriname"/utf8>>},
	{<<"sj">>, <<"Svalbard and Jan Mayen Islands"/utf8>>},
	{<<"sz">>, <<"Swaziland"/utf8>>},
	{<<"se">>, <<"Sweden"/utf8>>},
	{<<"ch">>, <<"Switzerland"/utf8>>},
	{<<"sy">>, <<"Syria"/utf8>>},
	{<<"tj">>, <<"Tajikistan"/utf8>>},
	{<<"tw">>, <<"Taiwan"/utf8>>},
	{<<"tz">>, <<"Tanzania"/utf8>>},
	{<<"th">>, <<"Thailand"/utf8>>},
	{<<"tg">>, <<"Togo"/utf8>>},
	{<<"tk">>, <<"Tokelau"/utf8>>},
	{<<"to">>, <<"Tonga"/utf8>>},
	{<<"tt">>, <<"Trinidad and Tobago"/utf8>>},
	{<<"tn">>, <<"Tunisia"/utf8>>},
	{<<"tr">>, <<"Turkey"/utf8>>},
	{<<"tm">>, <<"Turkmenistan"/utf8>>},
	{<<"tc">>, <<"Turks and Caicos Islands"/utf8>>},
	{<<"tv">>, <<"Tuvalu"/utf8>>},
	{<<"ug">>, <<"Uganda"/utf8>>},
	{<<"ua">>, <<"Ukraine"/utf8>>},
	{<<"ae">>, <<"United Arab Emirates"/utf8>>},
	{<<"gb">>, <<"United Kingdom"/utf8>>},
	{<<"us">>, <<"United States"/utf8>>},
	{<<"um">>, <<"United States Minor Outlying Islands"/utf8>>},
	{<<"uy">>, <<"Uruguay"/utf8>>},
	{<<"uz">>, <<"Uzbekistan"/utf8>>},
	{<<"vu">>, <<"Vanuatu"/utf8>>},
	{<<"ve">>, <<"Venezuela"/utf8>>},
	{<<"vn">>, <<"Vietnam"/utf8>>},
	{<<"vg">>, <<"Virgin Islands (British)"/utf8>>},
	{<<"vi">>, <<"Virgin Islands (USA)"/utf8>>},
	{<<"wf">>, <<"Wallis and Futuna Islands"/utf8>>},
	{<<"eh">>, <<"Western Sahara"/utf8>>},
	{<<"ye">>, <<"Yemen"/utf8>>},
	{<<"zm">>, <<"Zambia"/utf8>>},
	{<<"zw">>, <<"Zimbabwe"/utf8>>}
].
-else.
iso2country() -> [
	{<<"af">>, <<"Afghanistan">>},
	{<<"al">>, <<"Albania">>},
	{<<"ax">>, <<"Åland Islands"/utf8>>},
	{<<"dz">>, <<"Algeria">>},
	{<<"as">>, <<"American Samoa">>},
	{<<"ad">>, <<"Andorra">>},
	{<<"ao">>, <<"Angola">>},
	{<<"ai">>, <<"Anguilla">>},
	{<<"aq">>, <<"Antarctica">>},
	{<<"ag">>, <<"Antigua and Barbuda">>},
	{<<"ar">>, <<"Argentina">>},
	{<<"am">>, <<"Armenia">>},
	{<<"aw">>, <<"Aruba">>},
	{<<"au">>, <<"Australia">>},
	{<<"at">>, <<"Austria">>},
	{<<"az">>, <<"Azerbaijan">>},
	{<<"bs">>, <<"Bahamas">>},
	{<<"bh">>, <<"Bahrain">>},
	{<<"bd">>, <<"Bangladesh">>},
	{<<"bb">>, <<"Barbados">>},
	{<<"by">>, <<"Belarus">>},
	{<<"be">>, <<"Belgium">>},
	{<<"bz">>, <<"Belize">>},
	{<<"bj">>, <<"Benin">>},
	{<<"bm">>, <<"Bermuda">>},
	{<<"bt">>, <<"Bhutan">>},
	{<<"bo">>, <<"Bolivia">>},
	{<<"bq">>, <<"Bonaire, Sint Eustatius and Saba">>},
	{<<"ba">>, <<"Bosnia-Herzegovina">>},
	{<<"bw">>, <<"Botswana">>},
	{<<"bv">>, <<"Bouvet Island">>},
	{<<"br">>, <<"Brazil">>},
	{<<"io">>, <<"British Indian Ocean Territory">>},
	{<<"bn">>, <<"Brunei Darussalam">>},
	{<<"bg">>, <<"Bulgaria">>},
	{<<"bf">>, <<"Burkina Faso">>},
	{<<"bi">>, <<"Burundi">>},
	{<<"kh">>, <<"Cambodia">>},
	{<<"cm">>, <<"Cameroon">>},
	{<<"ca">>, <<"Canada">>},
	{<<"cv">>, <<"Cape Verde">>},
	{<<"ky">>, <<"Cayman Islands">>},
	{<<"cf">>, <<"Central African Republic">>},
	{<<"td">>, <<"Chad">>},
	{<<"cl">>, <<"Chile">>},
	{<<"cn">>, <<"China">>},
	{<<"cx">>, <<"Christmas Island">>},
	{<<"cc">>, <<"Cocos (Keeling) Islands">>},
	{<<"co">>, <<"Colombia">>},
	{<<"km">>, <<"Comoros">>},
	{<<"cg">>, <<"Congo">>},
	{<<"cd">>, <<"Congo, The Democratic Republic of the">>},
	{<<"ck">>, <<"Cook Islands">>},
	{<<"cr">>, <<"Costa Rica">>},
	{<<"hr">>, <<"Croatia">>},
	{<<"cu">>, <<"Cuba">>},
	{<<"cw">>, <<"Curaçao">>},
	{<<"cy">>, <<"Cyprus">>},
	{<<"cz">>, <<"Czech Republic">>},
	{<<"dk">>, <<"Denmark">>},
	{<<"dj">>, <<"Djibouti">>},
	{<<"dm">>, <<"Dominica">>},
	{<<"do">>, <<"Dominican Republic">>},
	{<<"tp">>, <<"East Timor">>},
	{<<"ec">>, <<"Ecuador">>},
	{<<"eg">>, <<"Egypt">>},
	{<<"sv">>, <<"El Salvador">>},
	{<<"gq">>, <<"Equatorial Guinea">>},
	{<<"er">>, <<"Eritrea">>},
	{<<"ee">>, <<"Estonia">>},
	{<<"et">>, <<"Ethiopia">>},
	{<<"fk">>, <<"Falkland Islands">>},
	{<<"fo">>, <<"Faroe Islands">>},
	{<<"fj">>, <<"Fiji">>},
	{<<"fi">>, <<"Finland">>},
	{<<"fr">>, <<"France">>},
	{<<"gf">>, <<"French Guiana">>},
	{<<"pf">>, <<"French Polynesia">>},
	{<<"tf">>, <<"French Southern Territories">>},
	{<<"ga">>, <<"Gabon">>},
	{<<"gm">>, <<"Gambia">>},
	{<<"ge">>, <<"Georgia">>},
	{<<"de">>, <<"Germany">>},
	{<<"gh">>, <<"Ghana">>},
	{<<"gi">>, <<"Gibraltar">>},
	{<<"gr">>, <<"Greece">>},
	{<<"gl">>, <<"Greenland">>},
	{<<"gd">>, <<"Grenada">>},
	{<<"gp">>, <<"Guadeloupe">>},
	{<<"gu">>, <<"Guam">>},
	{<<"gt">>, <<"Guatemala">>},
	{<<"gg">>, <<"Guernsey">>},
	{<<"gn">>, <<"Guinea">>},
	{<<"gw">>, <<"Guinea Bissau">>},
	{<<"gy">>, <<"Guyana">>},
	{<<"ht">>, <<"Haiti">>},
	{<<"hm">>, <<"Heard and McDonald Islands">>},
	{<<"va">>, <<"Holy See (Vatican City State)">>},
	{<<"hn">>, <<"Honduras">>},
	{<<"hk">>, <<"Hong Kong">>},
	{<<"hu">>, <<"Hungary">>},
	{<<"is">>, <<"Iceland">>},
	{<<"in">>, <<"India">>},
	{<<"id">>, <<"Indonesia">>},
	{<<"ir">>, <<"Iran">>},
	{<<"iq">>, <<"Iraq">>},
	{<<"ie">>, <<"Ireland">>},
	{<<"il">>, <<"Israel">>},
	{<<"im">>, <<"Isle of Man">>},
	{<<"it">>, <<"Italy">>},
	{<<"ci">>, <<"Ivory Coast (Cote D'Ivoire)">>},
	{<<"jm">>, <<"Jamaica">>},
	{<<"jp">>, <<"Japan">>},
	{<<"je">>, <<"Jersey">>},
	{<<"jo">>, <<"Jordan">>},
	{<<"kz">>, <<"Kazakhstan">>},
	{<<"ke">>, <<"Kenya">>},
	{<<"ki">>, <<"Kiribati">>},
	{<<"xk">>, <<"Kosovo">>},
	{<<"kw">>, <<"Kuwait">>},
	{<<"kg">>, <<"Kyrgyzstan">>},
	{<<"la">>, <<"Laos">>},
	{<<"lv">>, <<"Latvia">>},
	{<<"lb">>, <<"Lebanon">>},
	{<<"ls">>, <<"Lesotho">>},
	{<<"lr">>, <<"Liberia">>},
	{<<"ly">>, <<"Libya">>},
	{<<"li">>, <<"Liechtenstein">>},
	{<<"lt">>, <<"Lithuania">>},
	{<<"lu">>, <<"Luxembourg">>},
	{<<"mo">>, <<"Macao">>},
	{<<"mk">>, <<"Macedonia">>},
	{<<"mg">>, <<"Madagascar">>},
	{<<"mw">>, <<"Malawi">>},
	{<<"my">>, <<"Malaysia">>},
	{<<"mv">>, <<"Maldives">>},
	{<<"ml">>, <<"Mali">>},
	{<<"mt">>, <<"Malta">>},
	{<<"mh">>, <<"Marshall Islands">>},
	{<<"mq">>, <<"Martinique">>},
	{<<"mr">>, <<"Mauritania">>},
	{<<"mu">>, <<"Mauritius">>},
	{<<"yt">>, <<"Mayotte">>},
	{<<"mx">>, <<"Mexico">>},
	{<<"fm">>, <<"Micronesia">>},
	{<<"md">>, <<"Moldova">>},
	{<<"mc">>, <<"Monaco">>},
	{<<"mn">>, <<"Mongolia">>},
	{<<"me">>, <<"Montenegro">>},
	{<<"ms">>, <<"Montserrat">>},
	{<<"ma">>, <<"Morocco">>},
	{<<"mz">>, <<"Mozambique">>},
	{<<"mm">>, <<"Myanmar">>},
	{<<"na">>, <<"Namibia">>},
	{<<"nr">>, <<"Nauru">>},
	{<<"np">>, <<"Nepal">>},
	{<<"nl">>, <<"Netherlands">>},
	{<<"nc">>, <<"New Caledonia">>},
	{<<"nz">>, <<"New Zealand">>},
	{<<"ni">>, <<"Nicaragua">>},
	{<<"ne">>, <<"Niger">>},
	{<<"ng">>, <<"Nigeria">>},
	{<<"nu">>, <<"Niue">>},
	{<<"nf">>, <<"Norfolk Island">>},
	{<<"kp">>, <<"North Korea">>},
	{<<"mp">>, <<"Northern Mariana Islands">>},
	{<<"no">>, <<"Norway">>},
	{<<"om">>, <<"Oman">>},
	{<<"pk">>, <<"Pakistan">>},
	{<<"pw">>, <<"Palau">>},
	{<<"pa">>, <<"Panama">>},
	{<<"pg">>, <<"Papua New Guinea">>},
	{<<"py">>, <<"Paraguay">>},
	{<<"pe">>, <<"Peru">>},
	{<<"ph">>, <<"Philippines">>},
	{<<"pn">>, <<"Pitcairn Island">>},
	{<<"pl">>, <<"Poland">>},
	{<<"ps">>, <<"Palestinian Territory, Occupied">>},
	{<<"pt">>, <<"Portugal">>},
	{<<"pr">>, <<"Puerto Rico">>},
	{<<"qa">>, <<"Qatar">>},
	{<<"re">>, <<"Reunion">>},
	{<<"ro">>, <<"Romania">>},
	{<<"ru">>, <<"Russian Federation">>},
	{<<"rw">>, <<"Rwanda">>},
	{<<"gs">>, <<"South Georgia and the South Sandwich Islands">>},
	{<<"bl">>, <<"Saint Barthélemy">>},
	{<<"sh">>, <<"Saint Helena">>},
	{<<"kn">>, <<"Saint Kitts and Nevis Anguilla">>},
	{<<"lc">>, <<"Saint Lucia">>},
	{<<"mf">>, <<"Saint Martin (French)">>},
	{<<"sx">>, <<"Sint Maarten (Dutch)">>},
	{<<"pm">>, <<"Saint Pierre and Miquelon">>},
	{<<"st">>, <<"Sao Tome and Principe">>},
	{<<"vc">>, <<"Saint Vincent and Grenadines">>},
	{<<"ws">>, <<"Samoa">>},
	{<<"sm">>, <<"San Marino">>},
	{<<"sa">>, <<"Saudi Arabia">>},
	{<<"sn">>, <<"Senegal">>},
	{<<"rs">>, <<"Serbia">>},
	{<<"sc">>, <<"Seychelles">>},
	{<<"sl">>, <<"Sierra Leone">>},
	{<<"sg">>, <<"Singapore">>},
	{<<"sk">>, <<"Slovakia">>},
	{<<"si">>, <<"Slovenia">>},
	{<<"sb">>, <<"Solomon Islands">>},
	{<<"so">>, <<"Somalia">>},
	{<<"za">>, <<"South Africa">>},
	{<<"kr">>, <<"South Korea">>},
	{<<"ss">>, <<"South Sudan">>},
	{<<"es">>, <<"Spain">>},
	{<<"lk">>, <<"Sri Lanka">>},
	{<<"sd">>, <<"Sudan">>},
	{<<"sr">>, <<"Suriname">>},
	{<<"sj">>, <<"Svalbard and Jan Mayen Islands">>},
	{<<"sz">>, <<"Swaziland">>},
	{<<"se">>, <<"Sweden">>},
	{<<"ch">>, <<"Switzerland">>},
	{<<"sy">>, <<"Syria">>},
	{<<"tj">>, <<"Tajikistan">>},
	{<<"tw">>, <<"Taiwan">>},
	{<<"tz">>, <<"Tanzania">>},
	{<<"th">>, <<"Thailand">>},
	{<<"tg">>, <<"Togo">>},
	{<<"tk">>, <<"Tokelau">>},
	{<<"to">>, <<"Tonga">>},
	{<<"tt">>, <<"Trinidad and Tobago">>},
	{<<"tn">>, <<"Tunisia">>},
	{<<"tr">>, <<"Turkey">>},
	{<<"tm">>, <<"Turkmenistan">>},
	{<<"tc">>, <<"Turks and Caicos Islands">>},
	{<<"tv">>, <<"Tuvalu">>},
	{<<"ug">>, <<"Uganda">>},
	{<<"ua">>, <<"Ukraine">>},
	{<<"ae">>, <<"United Arab Emirates">>},
	{<<"gb">>, <<"United Kingdom">>},
	{<<"us">>, <<"United States">>},
	{<<"um">>, <<"United States Minor Outlying Islands">>},
	{<<"uy">>, <<"Uruguay">>},
	{<<"uz">>, <<"Uzbekistan">>},
	{<<"vu">>, <<"Vanuatu">>},
	{<<"ve">>, <<"Venezuela">>},
	{<<"vn">>, <<"Vietnam">>},
	{<<"vg">>, <<"Virgin Islands (British)">>},
	{<<"vi">>, <<"Virgin Islands (USA)">>},
	{<<"wf">>, <<"Wallis and Futuna Islands">>},
	{<<"eh">>, <<"Western Sahara">>},
	{<<"ye">>, <<"Yemen">>},
	{<<"zm">>, <<"Zambia">>},
	{<<"zw">>, <<"Zimbabwe">>}
].
-endif.

